@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '1.8.1'
-date = 'Sat Mar 11 23:51:58 2017'
+version = '1.10'
+date = 'Fri Oct  2 02:54:04 2015'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '1', '8.1', None)
+version_info = ('networkx', '1', '10', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2017, 3, 11, 23, 51, 58, 217555)
+date_info = datetime.datetime(2015, 10, 2, 2, 54, 4, 567752)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
